@@ -59,6 +59,7 @@ from .type_defs import (
     DescribeResourcePermissionsResponseTypeDef,
     DescribeRootFoldersResponseTypeDef,
     DescribeUsersResponseTypeDef,
+    EmptyResponseMetadataTypeDef,
     GetCurrentUserResponseTypeDef,
     GetDocumentPathResponseTypeDef,
     GetDocumentResponseTypeDef,
@@ -138,7 +139,7 @@ class WorkDocsClient(BaseClient):
 
     def abort_document_version_upload(
         self, *, DocumentId: str, VersionId: str, AuthenticationToken: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Aborts the upload of the specified document version that was previously
         initiated by  InitiateDocumentVersionUpload.
@@ -161,9 +162,9 @@ class WorkDocsClient(BaseClient):
         self,
         *,
         ResourceId: str,
-        Principals: Sequence["SharePrincipalTypeDef"],
+        Principals: Sequence[SharePrincipalTypeDef],
         AuthenticationToken: str = ...,
-        NotificationOptions: "NotificationOptionsTypeDef" = ...
+        NotificationOptions: NotificationOptionsTypeDef = ...
     ) -> AddResourcePermissionsResponseTypeDef:
         """
         Creates a set of permissions for the specified folder or document.
@@ -180,6 +181,14 @@ class WorkDocsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/workdocs.html#WorkDocs.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#close)
+        """
+
     def create_comment(
         self,
         *,
@@ -262,7 +271,7 @@ class WorkDocsClient(BaseClient):
         OrganizationId: str = ...,
         EmailAddress: str = ...,
         TimeZoneId: str = ...,
-        StorageRule: "StorageRuleTypeTypeDef" = ...,
+        StorageRule: StorageRuleTypeTypeDef = ...,
         AuthenticationToken: str = ...
     ) -> CreateUserResponseTypeDef:
         """
@@ -272,7 +281,9 @@ class WorkDocsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#create_user)
         """
 
-    def deactivate_user(self, *, UserId: str, AuthenticationToken: str = ...) -> None:
+    def deactivate_user(
+        self, *, UserId: str, AuthenticationToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deactivates the specified user, which revokes the user's access to Amazon
         WorkDocs.
@@ -283,7 +294,7 @@ class WorkDocsClient(BaseClient):
 
     def delete_comment(
         self, *, DocumentId: str, VersionId: str, CommentId: str, AuthenticationToken: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified comment from the document version.
 
@@ -307,7 +318,9 @@ class WorkDocsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#delete_custom_metadata)
         """
 
-    def delete_document(self, *, DocumentId: str, AuthenticationToken: str = ...) -> None:
+    def delete_document(
+        self, *, DocumentId: str, AuthenticationToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Permanently deletes the specified document and its associated metadata.
 
@@ -315,7 +328,9 @@ class WorkDocsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#delete_document)
         """
 
-    def delete_folder(self, *, FolderId: str, AuthenticationToken: str = ...) -> None:
+    def delete_folder(
+        self, *, FolderId: str, AuthenticationToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Permanently deletes the specified folder and its contents.
 
@@ -323,7 +338,9 @@ class WorkDocsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#delete_folder)
         """
 
-    def delete_folder_contents(self, *, FolderId: str, AuthenticationToken: str = ...) -> None:
+    def delete_folder_contents(
+        self, *, FolderId: str, AuthenticationToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the contents of the specified folder.
 
@@ -346,7 +363,9 @@ class WorkDocsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#delete_labels)
         """
 
-    def delete_notification_subscription(self, *, SubscriptionId: str, OrganizationId: str) -> None:
+    def delete_notification_subscription(
+        self, *, SubscriptionId: str, OrganizationId: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified subscription from the specified organization.
 
@@ -354,7 +373,9 @@ class WorkDocsClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_workdocs/client/#delete_notification_subscription)
         """
 
-    def delete_user(self, *, UserId: str, AuthenticationToken: str = ...) -> None:
+    def delete_user(
+        self, *, UserId: str, AuthenticationToken: str = ...
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified user from a Simple AD or Microsoft AD directory.
 
@@ -640,7 +661,7 @@ class WorkDocsClient(BaseClient):
 
     def remove_all_resource_permissions(
         self, *, ResourceId: str, AuthenticationToken: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes all the permissions from the specified resource.
 
@@ -655,7 +676,7 @@ class WorkDocsClient(BaseClient):
         PrincipalId: str,
         AuthenticationToken: str = ...,
         PrincipalType: PrincipalTypeType = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Removes the permission for the specified principal from the specified resource.
 
@@ -671,7 +692,7 @@ class WorkDocsClient(BaseClient):
         Name: str = ...,
         ParentFolderId: str = ...,
         ResourceState: ResourceStateTypeType = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Updates the specified attributes of a document.
 
@@ -686,7 +707,7 @@ class WorkDocsClient(BaseClient):
         VersionId: str,
         AuthenticationToken: str = ...,
         VersionStatus: Literal["ACTIVE"] = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Changes the status of the document version to ACTIVE.
 
@@ -702,7 +723,7 @@ class WorkDocsClient(BaseClient):
         Name: str = ...,
         ParentFolderId: str = ...,
         ResourceState: ResourceStateTypeType = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Updates the specified attributes of the specified folder.
 
@@ -718,7 +739,7 @@ class WorkDocsClient(BaseClient):
         GivenName: str = ...,
         Surname: str = ...,
         Type: UserTypeType = ...,
-        StorageRule: "StorageRuleTypeTypeDef" = ...,
+        StorageRule: StorageRuleTypeTypeDef = ...,
         TimeZoneId: str = ...,
         Locale: LocaleTypeType = ...,
         GrantPoweruserPrivileges: BooleanEnumTypeType = ...
